Name: cloudy
Version: 07.02.01
Release: 6%{?dist}
Summary: Spectral synthesis code to simulate conditions in interstellar matter

%define upversion 07_02_01

Group: Applications/Engineering
License: BSD
URL: http://www.nublado.org/
Source0: ftp://gradj.pa.uky.edu/gary/cloudy_gold/%{name}_v%{upversion}.tar.gz
Source1: cloudy_no_date_footer.tar.gz
Patch0: cloudy-doxygen.patch
Patch1: cloudy-shared.patch
Patch2: cloudy-hotfixes-20080214.patch
Buildroot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

Requires: %{name}-libs = %{version}-%{release}

BuildRequires: doxygen graphviz tetex-latex

%description
Most of the quantitative information we have about the cosmos comes from 
spectroscopy. In many cases the light we analyze was produced by atoms in 
the first generations of stars and galaxies.  The spectra are produced by 
dilute gas where such properties as the gas kinetic temperature, chemical 
state, level of ionization, and level populations, are determined by a 
host of microphysical processes rather than by a single temperature. 
Analytical solutions are seldom possible and computer solutions are 
needed to understand their physical properties. Numerical simulations make 
it possible to understand complex physical environments starting from 
first principles. Cloudy is designed to do exactly this.

%package devel
Summary: Headers for developing programs that will use %{name}
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}

%description devel
These are the header files and libraries needed to develop a %{name} 
application.

%package libs
Summary: Cloudy runtime libraries
Group: System Environment/Libraries
%description libs
Cloudy is a Spectral synthesis code to simulate conditions in 
interstellar matter.  This package contains the %{name} run-time library

%package docs
Summary: Documentation for %{name}, includes full API docs
Group: Documentation
BuildArch: noarch
 
%description docs
This package contains the full API documentation for %{name}.

%prep
%setup -q -n c%{version}
%setup -q -n c%{version} -T -D -a 1
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
cd source
CXX="%{__cxx}" CXXFLAGS="%{optflags}" CLOUDY_DATA_PATH=%{_datadir}/%{name}/data/ \
%{__make} %{?_smp_mflags}
cd ..
cd doxygen
doxygen Doxyfile
# Deleting empty files
find -empty -exec rm '{}' ';'
# Spurious file
find -name installdox -exec rm '{}' ';'

%install
%{__rm} -fr %{buildroot}
%{__mkdir_p} %{buildroot}/%{_bindir}
%{__mkdir_p} %{buildroot}/%{_libdir}
%{__mkdir_p} %{buildroot}/%{_includedir}/%{name}
%{__mkdir_p} %{buildroot}/%{_datadir}/%{name}/data
%{__mkdir_p} %{buildroot}/%{_datadir}/%{name}/scripts
%{__mkdir_p} %{buildroot}/%{_datadir}/%{name}/grain
%{__install} -m 755 source/cloudy.exe %{buildroot}/%{_bindir}/cloudy
%{__install} -m 755 source/libcloudy.so.* %{buildroot}/%{_libdir}
%{__cp} -a source/libcloudy.so %{buildroot}/%{_libdir}
%{__cp} -a source/cddefines.h %{buildroot}/%{_includedir}/%{name}
%{__cp} -a source/cpu.h %{buildroot}/%{_includedir}/%{name}
%{__cp} -a source/cddrive.h %{buildroot}/%{_includedir}/%{name}
%{__cp} -a data/*.opc %{buildroot}/%{_datadir}/%{name}/data
%{__cp} -a data/*.ini %{buildroot}/%{_datadir}/%{name}/data
%{__cp} -a data/*.dat %{buildroot}/%{_datadir}/%{name}/data
%{__cp} -a data/*.rfi %{buildroot}/%{_datadir}/%{name}/grain
%{__cp} -a data/*.szd %{buildroot}/%{_datadir}/%{name}/grain
%{__cp} -a data/*.in %{buildroot}/%{_datadir}/%{name}/scripts

%clean
%{__rm} -fr %{buildroot}

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc license.txt readme.txt docs/* 
%{_bindir}/*

%files libs
%defattr(-,root,root,-)
%doc license.txt data/readme_data.htm data/readme_LineList_dat.txt
%{_libdir}/lib%{name}.so.*
%{_datadir}/%{name}

%files devel
%defattr(-,root,root,-)
%doc license.txt 
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so

%files docs
%defattr(-,root,root,-)
%doc doxygen/html

%changelog
* Tue Jun 16 2009 Sergio Pascual <sergiopr at fedoraproject.org> 07.02.01-7
- Noarch subpackage for docs

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 07.02.01-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 01 2008 Sergio Pascual <sergiopr at fedoraproject.org> 07.02.01-5
- Directory not owned by package (bz #473639)

* Thu Mar 27 2008 Sergio Pascual <sergiopr at fedoraproject.org> 07.02.01-4
- Timestamps in footer of doxygen docs removed (bz #436495)

* Thu Mar 27 2008 Sergio Pascual <sergiopr at fedoraproject.org> 07.02.01-3
- Docs package is noarch (reverted)

* Sat Feb 24 2008 Sergio Pascual <sergiopr at fedoraproject.org> 07.02.01-2
- Too much files in docs

* Thu Feb 14 2008 Sergio Pascual <sergiopr at fedoraproject.org> 07.02.01-1
- Initial specfile
